@@ -199,7 +199,8 @@ class Application(VuetifyTemplate, HubListener):
         # The application handler stores the state of the data and the
         #  underlying glue infrastructure
         self._application_handler = JupyterApplication(
-            settings={'new_subset_on_selection_tool_change': True})
+            settings={'new_subset_on_selection_tool_change': True,
+                      'single_global_active_tool': False})
 
         # Add a reference to this application to the Glue session object. This
         # allows the jdaviz Application object to then be accessed via e.g.
@@ -941,8 +942,8 @@ class Application(VuetifyTemplate, HubListener):
             label = f'{stem}[{ext}]'
             return label
 
-    def add_data_to_viewer(self, viewer_reference, data_path,
-                           clear_other_data=False, ext=None):
+    def add_data_to_viewer(self, viewer_reference, data_label,
+                           clear_other_data=False):
         """
         Plots a data set from the data collection in the specific viewer.
 
@@ -951,21 +952,18 @@ class Application(VuetifyTemplate, HubListener):
         viewer_reference : str
             The reference to the viewer defined with the ``reference`` key
             in the yaml configuration file.
-        data_path : str
-            Either the data filename or the Glue data label found in the ``DataCollection``.
+        data_label : str
+            The Glue data label found in the ``DataCollection``.
         clear_other_data : bool
             Removes all other currently plotted data and only shows the newly
             defined data set.
-        ext: str
-            The data extension to access from a file.  If data_path is a filename, ext
-            is required.
         """
         viewer_item = self._viewer_item_by_reference(viewer_reference)
         if viewer_item is None:  # Maybe they mean the ID
             viewer_item = self._viewer_item_by_id(viewer_reference)
         if viewer_item is None:
             raise ValueError(f"Could not identify viewer with reference {viewer_reference}")
-        data_label = self._build_data_label(data_path, ext=ext)
+
         data_id = self._data_id_from_label(data_label)
 
         if clear_other_data:
@@ -977,6 +975,15 @@ class Application(VuetifyTemplate, HubListener):
             selected_data_items[data_id] = 'visible'
             self._update_selected_data_items(viewer_item['id'], selected_data_items)
         else:
+            # This block breaks backward compatibility with version<=3.0, where
+            # the second arg in `add_data_to_viewer` was `data_path` instead of
+            # `data_label`. When `data_label` is a file path and that file exists,
+            # raise an error which asks if user means to *load* data.
+            if os.path.exists(data_label):
+                raise ValueError(f'The data label "{data_label}" is not available '
+                                 f'to add to the viewer, but it does specify a file path. '
+                                 f'If you intended to load the data from that file, use the '
+                                 f'`load_data` method or similar.')
             raise ValueError(
                 f"No data item found with label '{data_label}'. Label must be one "
                 "of:\n\t" + "\n\t".join([
@@ -995,7 +1002,7 @@ class Application(VuetifyTemplate, HubListener):
 
         viewer.set_plot_axes()
 
-    def remove_data_from_viewer(self, viewer_reference, data_path, ext=None):
+    def remove_data_from_viewer(self, viewer_reference, data_label):
         """
         Removes a data set from the specified viewer.
 
@@ -1004,14 +1011,10 @@ class Application(VuetifyTemplate, HubListener):
         viewer_reference : str
             The reference to the viewer defined with the ``reference`` key
             in the yaml configuration file.
-        data_path : str
-            Either the data filename or the Glue data label found in the ``DataCollection``.
-        ext: str
-            The data extension to access from a file.  If data_path is a filename, ext
-            is required.
+        data_label : str
+            The Glue data label found in the ``DataCollection``.
         """
         viewer_item = self._viewer_item_by_reference(viewer_reference)
-        data_label = self._build_data_label(data_path, ext=ext)
         data_id = self._data_id_from_label(data_label)
 
         selected_items = viewer_item['selected_data_items']
@@ -1308,6 +1311,8 @@ class Application(VuetifyTemplate, HubListener):
 
         color_cycler = ColorCycler()
 
+        viewer_data_labels = [layer.layer.label for layer in viewer.layers]
+
         # Include any selected data in the viewer
         for data_id, visibility in selected_items.items():
             label = self._get_data_item_by_id(data_id)['name']
@@ -1319,14 +1324,14 @@ class Application(VuetifyTemplate, HubListener):
 
             active_data_labels.append(label)
 
-            [data] = [x for x in self.data_collection if x.label == label]
+            if label not in viewer_data_labels:
+                [data] = [x for x in self.data_collection if x.label == label]
+                viewer.add_data(data, percentile=95, color=color_cycler())
 
-            viewer.add_data(data, percentile=95, color=color_cycler())
-
-            add_data_message = AddDataMessage(data, viewer,
-                                              viewer_id=viewer_id,
-                                              sender=self)
-            self.hub.broadcast(add_data_message)
+                add_data_message = AddDataMessage(data, viewer,
+                                                  viewer_id=viewer_id,
+                                                  sender=self)
+                self.hub.broadcast(add_data_message)
 
             for layer in viewer.layers:
                 if layer.layer.data.label == label:
@@ -1498,10 +1503,6 @@ class Application(VuetifyTemplate, HubListener):
         dict
             Dictionary containing information for this viewer item.
         """
-        tools = viewer.toolbar_selection_tools
-        tools.borderless = True
-        tools.tile = True
-
         if vid is None:
             pfx = self.state.settings.get('configuration', str(name))
             n = self._next_viewer_num(pfx)
@@ -1518,9 +1519,7 @@ class Application(VuetifyTemplate, HubListener):
             'id': vid,
             'name': name or vid,
             'widget': "IPY_MODEL_" + viewer.figure_widget.model_id,
-            'toolbar_nested': "IPY_MODEL_" + viewer.toolbar_nested.model_id if viewer.toolbar_nested else '',  # noqa
-            'tools': "IPY_MODEL_" + viewer.toolbar_selection_tools.model_id,
-            'tools_open': False,
+            'toolbar': "IPY_MODEL_" + viewer.toolbar.model_id if viewer.toolbar else '',  # noqa
             'layer_options': "IPY_MODEL_" + viewer.layer_options.model_id,
             'viewer_options': "IPY_MODEL_" + viewer.viewer_options.model_id,
             'selected_data_items': {},  # data-label: visibility state (visible, hidden, mixed)
@@ -1564,7 +1563,9 @@ class Application(VuetifyTemplate, HubListener):
         # Create the viewer item dictionary
         if name is None:
             name = viewer.__class__.__name__
-        new_viewer_item = self._create_viewer_item(viewer=viewer, vid=vid, name=name)
+        new_viewer_item = self._create_viewer_item(
+            viewer=viewer, vid=vid, name=name, reference=name
+        )
 
         new_stack_item = self._create_stack_item(
             container='gl-stack',
