@@ -20,15 +20,63 @@ from ipypopout import PopoutButton
 from jdaviz import __version__
 from jdaviz.core.events import (AddDataMessage, RemoveDataMessage,
                                 ViewerAddedMessage, ViewerRemovedMessage)
+from jdaviz.core.user_api import UserApiWrapper, PluginUserApi
 
 
-__all__ = ['TemplateMixin', 'PluginTemplateMixin',
-           'BasePluginComponent', 'BaseSelectPluginComponent',
+__all__ = ['show_widget', 'TemplateMixin', 'PluginTemplateMixin',
+           'BasePluginComponent', 'SelectPluginComponent',
            'SubsetSelect', 'SpatialSubsetSelectMixin', 'SpectralSubsetSelectMixin',
            'ViewerSelect', 'ViewerSelectMixin',
+           'LayerSelect', 'LayerSelectMixin',
            'DatasetSelect', 'DatasetSelectMixin',
-           'AutoLabel', 'AutoLabelMixin',
-           'AddResults', 'AddResultsMixin']
+           'AutoTextField', 'AutoTextFieldMixin',
+           'AddResults', 'AddResultsMixin',
+           'PlotOptionsSyncState']
+
+
+def show_widget(widget, loc, title):  # pragma: no cover
+    from IPython import get_ipython
+    from IPython.display import display
+
+    # Check if the user is running Jdaviz in the correct environments.
+    # If not, provide a friendly msg to guide them!
+    cur_shell_name = get_ipython().__class__.__name__
+    if cur_shell_name != 'ZMQInteractiveShell':
+        raise RuntimeError("\nYou are currently running Jdaviz from an unsupported "
+                           f"shell ({cur_shell_name}). Jdaviz is intended to be run within a "
+                           "Jupyter notebook, or directly from the command line.\n\n"
+                           "To run from Jupyter, call <your viz>.show() from a notebook cell.\n"
+                           "To see how to run from the command line, run: "
+                           "'jdaviz --help' outside of Python.\n\n"
+                           "To learn more, see our documentation at: "
+                           "https://jdaviz.readthedocs.io")
+
+    if loc == "inline":
+        display(widget)
+
+    elif loc.startswith('sidecar'):
+        from sidecar import Sidecar
+
+        # Use default behavior if loc is exactly 'sidecar', else split anchor from the arg
+        anchor = None if loc == 'sidecar' else loc.split(':')[1]
+
+        scar = Sidecar(anchor=anchor, title=title)
+        with scar:
+            display(widget)
+
+    elif loc.startswith('popout'):
+        anchor = None if loc == 'popout' else loc.split(':')[1]
+
+        # Default behavior (no anchor specified): display popout in new window
+        if anchor in (None, 'window'):
+            widget.popout_button.open_window()
+        elif anchor == "tab":
+            widget.popout_button.open_tab()
+        else:
+            raise ValueError("Unrecognized popout anchor")
+
+    else:
+        raise ValueError(f"Unrecognized display location: {loc}")
 
 
 class TemplateMixin(VuetifyTemplate, HubListener):
@@ -91,11 +139,17 @@ class PluginTemplateMixin(TemplateMixin):
     disabled_msg = Unicode("").tag(sync=True)
     plugin_opened = Bool(False).tag(sync=True)
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
         self.app.state.add_callback('tray_items_open', self._mxn_update_plugin_opened)
         self.app.state.add_callback('drawer', self._mxn_update_plugin_opened)
 
+    @property
+    def user_api(self):
+        # plugins should override this to pass their own list of expose functionality, which
+        # can even be dependent on config, etc.
+        return PluginUserApi(self, expose=[])
+
     def _mxn_update_plugin_opened(self, new_value):
         app_state = self.app.state
         tray_names_open = [app_state.tray_items[i]['name'] for i in app_state.tray_items_open]
@@ -111,6 +165,54 @@ class PluginTemplateMixin(TemplateMixin):
         if index not in app_state.tray_items_open:
             app_state.tray_items_open = app_state.tray_items_open + [index]
 
+    def show(self, loc="inline", title=None):  # pragma: no cover
+        """Display the plugin UI.
+
+        Parameters
+        ----------
+        loc : str
+            The display location determines where to present the viz app.
+            Supported locations:
+
+            "inline": Display the plugin inline in a notebook.
+
+            "sidecar": Display the plugin in a separate JupyterLab window from the
+            notebook, the location of which is decided by the 'anchor.' right is the default
+
+                Other anchors:
+
+                * ``sidecar:right`` (The default, opens a tab to the right of display)
+                * ``sidecar:tab-before`` (Full-width tab before the current notebook)
+                * ``sidecar:tab-after`` (Full-width tab after the current notebook)
+                * ``sidecar:split-right`` (Split-tab in the same window right of the notebook)
+                * ``sidecar:split-left`` (Split-tab in the same window left of the notebook)
+                * ``sidecar:split-top`` (Split-tab in the same window above the notebook)
+                * ``sidecar:split-bottom`` (Split-tab in the same window below the notebook)
+
+                See `jupyterlab-sidecar <https://github.com/jupyter-widgets/jupyterlab-sidecar>`_
+                for the most up-to-date options.
+
+            "popout": Display the plugin in a detached display. By default, a new
+            window will open. Browser popup permissions required.
+
+                Other anchors:
+
+                * ``popout:window`` (The default, opens Jdaviz in a new, detached popout)
+                * ``popout:tab`` (Opens Jdaviz in a new, detached tab in your browser)
+
+        title : str, optional
+            The title of the sidecar tab.  Defaults to the name of the plugin.
+
+            NOTE: Only applicable to a "sidecar" display.
+
+        Notes
+        -----
+        If "sidecar" is requested in the "classic" Jupyter notebook, the plugin will appear inline,
+        as only JupyterLab has a mechanism to have multiple tabs.
+        """
+        title = title if title is not None else self._registry_label
+        show_widget(self, loc=loc, title=title)
+
 
 class BasePluginComponent(HubListener):
     """
@@ -199,19 +301,32 @@ class BasePluginComponent(HubListener):
         return self._plugin.app.get_viewer("spectrum-viewer")
 
 
-class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
+class SelectPluginComponent(BasePluginComponent, HasTraits):
     """
-    This base class extends BasePluginComponent for common functionality for a select/dropdown
-    component.  The subclasses MUST have an ``items`` traitlet as a list of dictionaries, with
-    'label' as the selection entry (and any other optional entries for styling, etc) and a
-    ``selected`` string traitlet.  The subclasses should also override ``selected_obj`` and may
-    choose to override ``_selected_changed`` (likely with a super call to keep the base logic).
+    Plugin select, with support for single or multi-selection.
+
+    Useful API methods/attributes:
+
+    * :meth:`choices`
+    * ``selected``
+    * :meth:`~SelectPluginComponent.is_multiselect`
+    * :meth:`select_default`
+    * :meth:`select_all` (only if ``is_multiselect``)
+    * :meth:`select_none` (only if ``is_multiselect``)
     """
     filters = List([]).tag(sync=True)
 
     def __init__(self, *args, **kwargs):
+        """
+        This extends BasePluginComponent for common functionality for a select/dropdown
+        component.  The subclasses MUST have an ``items`` traitlet as a list of dictionaries, with
+        'label' as the selection entry (and any other optional entries for styling, etc) and a
+        ``selected`` string traitlet.  The subclasses should also override ``selected_obj`` and may
+        choose to override ``_selected_changed`` (likely with a super call to keep the base logic).
+        """
+
         # default_mode can be one of empty, first, default_text (requires default_text to be set)
-        default_mode = kwargs.pop('default_mode', 'empty')
+        default_mode = kwargs.pop('default_mode', 'empty' if kwargs.get('multiselect', False) else 'first')  # noqa
         default_text = kwargs.pop('default_text', None)
         manual_options = kwargs.pop('manual_options', [])
         self._viewers = kwargs.pop('viewers', None)
@@ -242,6 +357,25 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
         self.add_observe(kwargs.get('selected'), self._selected_changed, first=True)
         self.filters = filters
 
+        if default_mode != 'empty' and self.selected == '':
+            self._apply_default_selection()
+
+    def __repr__(self):
+        if hasattr(self, 'multiselect'):
+            return f"<selected={self.selected} multiselect={self.multiselect} choices={self.choices}>"  # noqa
+        return f"<selected={self.selected} choices={self.choices}>"
+
+    def __eq__(self, other):
+        return self.selected == other
+
+    def __hash__(self):
+        # defining __eq__ without defining __hash__ makes the object unhashable
+        return super().__hash__()
+
+    @property
+    def choices(self):
+        return self.labels
+
     @property
     def is_multiselect(self):
         if not hasattr(self, 'multiselect'):
@@ -249,6 +383,31 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
         else:
             return self.multiselect
 
+    def select_default(self):
+        """
+        Apply and return the default selection.
+        """
+        self._apply_default_selection(skip_if_current_valid=False)
+        return self.selected
+
+    def select_all(self):
+        """
+        Select (and return) all available options.  Raises an error if not :meth:`is_multiselect`
+        """
+        if not self.is_multiselect:
+            raise ValueError("not currently in multiselect mode")
+        self.selected = self.choices
+        return self.selected
+
+    def select_none(self):
+        """
+        Select (and return) and empty list.  Raises an error if not :meth:`is_multiselect`
+        """
+        if not self.is_multiselect:
+            raise ValueError("not currently in multiselect mode")
+        self.selected = []
+        return self.selected
+
     @property
     def default_text(self):
         return self._default_text
@@ -313,7 +472,7 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
     def default_mode(self):
         return self._default_mode
 
-    def _apply_default_selection(self):
+    def _apply_default_selection(self, skip_if_current_valid=True):
         # TODO: make this multi-ready
         is_valid = self.selected in self.labels
         if callable(self.default_mode):
@@ -324,7 +483,7 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
             self.selected = self.default_mode(self, is_valid=is_valid)
             return
 
-        if is_valid:
+        if is_valid and skip_if_current_valid:
             # current selection is valid
             return
 
@@ -364,17 +523,31 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
                 self.selected = [event['new']]
                 return
             if not np.all([item in self.labels + [''] for item in event['new']]):
-                self._apply_default_selection()
-                raise ValueError(f"not all items in {event['new']} are one of {self.labels}")
+                self.selected = event['old']
+                raise ValueError(f"not all items in {event['new']} are one of {self.labels}, reverting selection to {event['old']}")  # noqa
         else:
             if event['new'] not in self.labels + ['']:
-                self._apply_default_selection()
-                raise ValueError(f"{event['new']} not one of {self.labels}")
+                self.selected = event['old']
+                raise ValueError(f"{event['new']} not one of {self.labels}, reverting selection to {event['old']}")  # noqa
 
 
-class LayerSelect(BaseSelectPluginComponent):
+class LayerSelect(SelectPluginComponent):
     """
-    Traitlets (in the object, custom traitlets in the plugin):
+    Plugin select for layers, with support for single or multi-selection.
+
+    Useful API methods/attributes:
+
+    * :meth:`~SelectPluginComponent.choices`
+    * ``selected``
+    * :meth:`~SelectPluginComponent.is_multiselect`
+    * :meth:`~SelectPluginComponent.select_default`
+    * :meth:`~SelectPluginComponent.select_all` (only if ``is_multiselect``)
+    * :meth:`~SelectPluginComponent.select_none` (only if ``is_multiselect``)
+    * :attr:`selected_obj`
+    """
+
+    """
+    Traitlets (in the object, custom traitlets in the plugin
 
     * ``items`` (list of dicts with keys: label, color)
     * ``selected`` (string)
@@ -405,7 +578,6 @@ class LayerSelect(BaseSelectPluginComponent):
         label="Layer"
         hint="Select layer."
       />
-
     """
     def __init__(self, plugin, items, selected, viewer,
                  multiselect=None,
@@ -563,7 +735,23 @@ class LayerSelectMixin(VuetifyTemplate, HubListener):
                                  'layer_multiselect')
 
 
-class SubsetSelect(BaseSelectPluginComponent):
+class SubsetSelect(SelectPluginComponent):
+    """
+    Plugin select for subsets, with support for single or multi-selection.
+
+    Useful API methods/attributes:
+
+    * :meth:`~SelectPluginComponent.choices`
+    * ``selected``
+    * :meth:`~SelectPluginComponent.is_multiselect`
+    * :meth:`~SelectPluginComponent.select_default`
+    * :meth:`~SelectPluginComponent.select_all` (only if ``is_multiselect``)
+    * :meth:`~SelectPluginComponent.select_none` (only if ``is_multiselect``)
+    * :attr:`selected_obj`
+    * :attr:`selected_subset_state`
+    * :meth:`selected_min_max`
+    """
+
     """
     Traitlets (in the object, custom traitlets in the plugin):
 
@@ -823,7 +1011,22 @@ class SpatialSubsetSelectMixin(VuetifyTemplate, HubListener):
                                            allowed_type='spatial')
 
 
-class ViewerSelect(BaseSelectPluginComponent):
+class ViewerSelect(SelectPluginComponent):
+    """
+    Plugin select for viewers, with support for single or multi-selection.
+
+    Useful API methods/attributes:
+
+    * :meth:`~SelectPluginComponent.choices`
+    * ``selected``
+    * :attr:`selected_id`
+    * :attr:`selected_obj`
+    * :meth:`~SelectPluginComponent.is_multiselect`
+    * :meth:`~SelectPluginComponent.select_default`
+    * :meth:`~SelectPluginComponent.select_all` (only if ``is_multiselect``)
+    * :meth:`~SelectPluginComponent.select_none` (only if ``is_multiselect``)
+    """
+
     """
     Traitlets (in the object, custom traitlets in the plugin):
 
@@ -926,7 +1129,8 @@ class ViewerSelect(BaseSelectPluginComponent):
                 elif entry in self.ids:
                     new_selected.append(self.labels[self.ids.index(entry)])
                 else:
-                    raise ValueError(f"could not map {entry} to valid choice")
+                    self.selected = event['old']
+                    raise ValueError(f"could not map {entry} to valid choice, reverting selection to {event['old']}")  # noqa
             self.selected = new_selected
             return
         else:
@@ -991,7 +1195,22 @@ class ViewerSelectMixin(VuetifyTemplate, HubListener):
         self.viewer = ViewerSelect(self, 'viewer_items', 'viewer_selected', 'viewer_multiselect')
 
 
-class DatasetSelect(BaseSelectPluginComponent):
+class DatasetSelect(SelectPluginComponent):
+    """
+    Plugin select for data entries, with support for single or multi-selection.
+
+    Useful API methods/attributes:
+
+    * :meth:`~SelectPluginComponent.choices`
+    * ``selected``
+    * :attr:`selected_obj`
+    * :attr:`selected_dc_item`
+    * :meth:`~SelectPluginComponent.is_multiselect`
+    * :meth:`~SelectPluginComponent.select_default`
+    * :meth:`~SelectPluginComponent.select_all` (only if ``is_multiselect``)
+    * :meth:`~SelectPluginComponent.select_none` (only if ``is_multiselect``)
+    """
+
     """
     Traitlets (in the object, custom traitlets in the plugin):
 
@@ -1055,6 +1274,7 @@ class DatasetSelect(BaseSelectPluginComponent):
         # Add/Remove Data are triggered when checked/unchecked from viewers
         self.hub.subscribe(self, AddDataMessage, handler=self._on_data_changed)
         self.hub.subscribe(self, RemoveDataMessage, handler=self._on_data_changed)
+        self.hub.subscribe(self, DataCollectionAddMessage, handler=self._on_data_changed)
         self.hub.subscribe(self, DataCollectionDeleteMessage, handler=self._on_data_changed)
 
         self.app.state.add_callback('layer_icons', lambda _: self._on_data_changed())
@@ -1065,6 +1285,8 @@ class DatasetSelect(BaseSelectPluginComponent):
     def default_data_cls(self):
         if self.app.config == 'imviz':
             return None
+        if 'is_trace' in self.filters:
+            return None
         return Spectrum1D
 
     @cached_property
@@ -1192,7 +1414,18 @@ class DatasetSelectMixin(VuetifyTemplate, HubListener):
         self.dataset = DatasetSelect(self, 'dataset_items', 'dataset_selected')
 
 
-class AutoLabel(BasePluginComponent):
+class AutoTextField(BasePluginComponent):
+    """
+    Label component with the ability to synchronize to a plugin-provided default value or override
+    with a custom value.  Setting ``value`` will set ``auto`` to False.  Setting ``auto`` to True,
+    will set ``value`` to the default value.
+
+    Useful API methods/attributes:
+
+    * ``value``
+    * ``auto``
+    """
+
     """
     Traitlets (in the object, custom traitlets in the plugin):
 
@@ -1224,21 +1457,31 @@ class AutoLabel(BasePluginComponent):
         self.add_observe(default, self._on_set_to_default)
         self.add_observe(auto, self._on_set_to_default)
 
+    def __repr__(self):
+        return f"<AutoTextField label='{self.value}' auto={self.auto}>"
+
+    def __eq__(self, other):
+        return self.value == other
+
+    def __hash__(self):
+        # defining __eq__ without defining __hash__ makes the object unhashable
+        return super().__hash__()
+
     def _on_set_to_default(self, msg={}):
         if self.auto:
             self.value = self.default
 
 
-class AutoLabelMixin(VuetifyTemplate, HubListener):
+class AutoTextFieldMixin(VuetifyTemplate, HubListener):
     """
-    Applies the AutoLabel component as a mixin in the base plugin.  This
+    Applies the AutoTextField component as a mixin in the base plugin.  This
     automatically adds traitlets as well as new properties to the plugin with minimal
     extra code.  For multiple instances or custom traitlet names/defaults, use the
     component instead.
 
     To use in a plugin:
 
-    * add ``AutoLabelMixin`` as a mixin to the class
+    * add ``AutoTextFieldMixin`` as a mixin to the class
     * use the traitlets available from the plugin or properties/methods available from
       ``plugin.auto_label``.
 
@@ -1265,6 +1508,21 @@ class AutoLabelMixin(VuetifyTemplate, HubListener):
 
 
 class AddResults(BasePluginComponent):
+    """
+    Plugin component for providing a data-label and selecting a viewer to add the results from
+    the plugin.
+
+    Useful API methods/attributes:
+
+    * :attr:`label` (`AutoTextField`):
+        the label component.  Setting will redirect to setting ``label.value``.
+    * :attr:`auto`
+        shortcut to ``label.auto``.  Setting will redirect to setting ``label.auto``.
+    * ``viewer`` (`ViewerSelect`):
+        the viewer to add the results, or None to add the results to the data-collection but
+        not load into a viewer.
+    """
+
     """
     Traitlets (in the object, custom traitlets in the plugin):
 
@@ -1328,9 +1586,41 @@ class AddResults(BasePluginComponent):
                                    manual_options=['None'],
                                    default_mode=self._handle_default_viewer_selected)
 
-        self.auto_label = AutoLabel(plugin, label, label_default, label_auto, label_invalid_msg)
+        self.auto_label = AutoTextField(plugin, label, label_default, label_auto, label_invalid_msg)
+        self.auto = self.auto_label.auto
         self.add_observe(label, self._on_label_changed)
 
+    def __repr__(self):
+        return f"<AddResults label='{self.label}', auto={self.auto}, viewer={self.viewer.selected}>"
+
+    @property
+    def user_api(self):
+        return UserApiWrapper(self, ('label', 'auto', 'viewer'))
+
+    @property
+    def label(self):
+        """
+        Access the value of the ``AutoTextField`` object.  Changing the value manually will also
+        disable the ``auto`` option.
+        """
+        return self.auto_label.value
+
+    @label.setter
+    def label(self, label):
+        self.auto_label.value = label
+
+    @property
+    def auto(self):
+        """
+        Access the ``auto`` property of the ``AutoTextField`` object.  If enabling, the ``label``
+        will automatically be changed and kept in sync with the default label.
+        """
+        return self.auto_label.auto
+
+    @auto.setter
+    def auto(self, auto):
+        self.auto_label.auto = auto
+
     def _handle_default_viewer_selected(self, viewer_comp, is_valid):
         if len(viewer_comp.items) == 2:
             # then we're a switch, so we want to default to ON
@@ -1463,6 +1753,15 @@ class AddResultsMixin(VuetifyTemplate, HubListener):
 
 class PlotOptionsSyncState(BasePluginComponent):
     """
+    Plugin component for syncing with glue state objects.
+
+    Useful API methods/attributes:
+
+    * ``value``: the currently set value sent to the underlying ``linked_states`` objects in glue
+    * ``text``: the user-friendly equivalent of the currently set value (only when has ``choices``)
+    * :meth:`choices` (only when applicable)
+    * :attr:`linked_states`
+    * :meth:`unmix_state`
     """
     def __init__(self, plugin, viewer_select, layer_select, glue_name,
                  value, sync, state_filter=None):
@@ -1481,6 +1780,40 @@ class PlotOptionsSyncState(BasePluginComponent):
         self.add_observe(value, self._on_value_changed)
         self._on_viewer_layer_changed()
 
+    def __repr__(self):
+        choices = self.choices
+        if len(choices):
+            return f"<PlotOptionsSyncState {self._glue_name}={self.value} choices={self.choices} (linked_states: {len(self.linked_states)}/{len(self.subscribed_states)})>"  # noqa
+        return f"<PlotOptionsSyncState {self._glue_name}={self.value} (linked_states: {len(self.linked_states)}/{len(self.subscribed_states)})>"  # noqa
+
+    @property
+    def user_api(self):
+        expose = ['value', 'unmix_state', 'linked_states']
+        if len(self.choices):
+            expose += ['choices', 'text']
+        return UserApiWrapper(self, expose=expose)
+
+    def __eq__(self, other):
+        return self.value == other or (len(self.choices) and self.text == other)
+
+    def __hash__(self):
+        # defining __eq__ without defining __hash__ makes the object unhashable
+        return super().__hash__()
+
+    @property
+    def text(self):
+        """
+        The user-friendly text equivalent of the currently set value
+        """
+        value = self.value
+        for choice in self.sync.get('choices', {}):
+            if choice['value'] == value:
+                return choice['text']
+
+    @property
+    def choices(self):
+        return [choice['text'] for choice in self.sync.get('choices', {})]
+
     def state_filter(self, state):
         if self._state_filter is None:
             return True
@@ -1550,6 +1883,10 @@ class PlotOptionsSyncState(BasePluginComponent):
     def _get_glue_value(self, state):
         if self._glue_name == 'cmap':
             return getattr(state, self._glue_name).name
+        if self._glue_name in ['contour_visible', 'bitmap_visible']:
+            # return False if the layer itself is not visible.  Setting this object
+            # to True will then set both glue_name and visible to True.
+            return getattr(state, self._glue_name) and getattr(state, 'visible')
         return getattr(state, self._glue_name)
 
     def _get_glue_choices(self, state):
@@ -1568,6 +1905,8 @@ class PlotOptionsSyncState(BasePluginComponent):
         # clear existing callbacks - we'll re-create those we need later
         for state in self.linked_states:
             state.remove_callback(self._glue_name, self._on_glue_value_changed)
+            if self._glue_name in ['contour_visible', 'bitmap_visible']:
+                state.remove_callback('visible', self._on_glue_layer_visible_changed)
 
         in_subscribed_states = False
         icons = []
@@ -1589,6 +1928,8 @@ class PlotOptionsSyncState(BasePluginComponent):
                 current_glue_values.append(self._get_glue_value(state))
                 self._linked_states.append(state)  # these will be iterated when value is set
                 state.add_callback(self._glue_name, self._on_glue_value_changed)
+                if self._glue_name in ['contour_visible', 'bitmap_visible']:
+                    state.add_callback('visible', self._on_glue_layer_visible_changed)
 
                 if self.sync.get('choices') is None and \
                         (hasattr(getattr(type(state), self._glue_name), 'get_display_func')
@@ -1635,10 +1976,28 @@ class PlotOptionsSyncState(BasePluginComponent):
                 setattr(glue_state, self._glue_name, cmap)
             else:
                 setattr(glue_state, self._glue_name, msg['new'])
+
+            if self._glue_name in ['bitmap_visible', 'contour_visible'] and msg['new'] is True:
+                # ensure that the layer is also visible
+                setattr(glue_state, 'visible', msg['new'])
+
         # need to recompute mixed state
         self._update_mixed_state()
         self._processing_change_to_glue = False
 
+    def _on_glue_layer_visible_changed(self, value):
+        # this is only triggered for glue_name contour_visible or bitmap_visible
+        self._processing_change_from_glue = True
+        if value is False:
+            self.value = False
+        elif len(self.linked_states):
+            # then this is a little tricky since we don't have the calling state object,
+            # instead we'll set the value based on the first state object and will still
+            # make a call to update the mixed state
+            self.value = self._get_glue_value(self.linked_states[0])
+        self._processing_change_from_glue = False
+        self._update_mixed_state()
+
     def _on_glue_value_changed(self, value):
         if self._glue_name == 'color_mode':
             # then we need to force updates to the layer-icon colors
